@@ -4,9 +4,9 @@ use warnings;
 use strict;
 use 5.008003;
 
-our $VERSION = '0.518';
+our $VERSION = '0.519';
 use Exporter 'import';
-our @EXPORT_OK = qw( fill_form settings_menu read_line );
+our @EXPORT_OK = qw( fill_form read_line );
 
 use Carp       qw( croak carp );
 use List::Util qw( any );
@@ -1231,10 +1231,6 @@ sub __print_previous_page {
 
 
 
-
-
-
-
 1;
 
 __END__
@@ -1249,7 +1245,7 @@ Term::Form - Read lines from STDIN.
 
 =head1 VERSION
 
-Version 0.518
+Version 0.519
 
 =cut
 
